@@ -228,7 +228,7 @@ static void vlogLogPrint(
   const char *zArg3,               /* Third argument */
   int iRes                         /* Result */
 ){
-  char z1[40], z2[40], z3[2000];
+  char z1[40], z2[40], z3[2000], zStart[40], zElapse[40];
   if( pLog==0 ) return;
   if( iArg1>=0 ){
     sqlite3_snprintf(sizeof(z1), z1, "%lld", iArg1);
@@ -245,8 +245,10 @@ static void vlogLogPrint(
   }else{
     z3[0] = 0;
   }
-  fprintf(pLog->out,"%lld,%lld,%s,%d,%s,%s,%s,%d\n",
-      tStart, tElapse, zOp, pLog->zFilename==0, z1, z2, z3, iRes);
+  sqlite3_snprintf(sizeof(zStart), zStart, "%lld", tStart);
+  sqlite3_snprintf(sizeof(zElapse), zElapse, "%lld", tElapse);
+  fprintf(pLog->out,"%s,%s,%s,%d,%s,%s,%s,%d\n",
+      zStart, zElapse, zOp, pLog->zFilename==0, z1, z2, z3, iRes);
 }
 
 /*
